Tutorial 5: Large Datasets
===========================

.. deprecated::
   This tutorial has been superseded by the structured tutorial guide.

See :doc:`/tutorials/routine/data_handling/large_datasets` for the updated version.
